Simple test
------------

Ensure your device works with this simple test.

.. literalinclude:: ../examples/clue_simpletest.py
    :caption: examples/clue_simpletest.py
    :linenos:

.. literalinclude:: ../examples/clue_display_sensor_data.py
    :caption: examples/clue_display_sensor_data.py
    :linenos:
